@@ -1,7 +1,7 @@
 /** @file documentvaluelist.h
  * @brief Iteration over values in a document.
  */
-/* Copyright (C) 2007,2008,2009 Olly Betts
+/* Copyright (C) 2007,2008,2009,2011 Olly Betts
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -21,9 +21,9 @@
 #ifndef XAPIAN_INCLUDED_DOCUMENTVALUELIST_H
 #define XAPIAN_INCLUDED_DOCUMENTVALUELIST_H
 
-#include "valuelist.h"
+#include "backends/valuelist.h"
 
-#include "document.h"
+#include "backends/document.h"
 
 /// Iteration over values in a document.
 class DocumentValueList : public ValueList {
@@ -34,7 +34,7 @@ class DocumentValueList : public ValueList {
     DocumentValueList(const DocumentValueList &);
 
     /// Document internals we're iterating over.
-    Xapian::Internal::RefCntPtr<const Xapian::Document::Internal> doc;
+    Xapian::Internal::intrusive_ptr<const Xapian::Document::Internal> doc;
 
     /** Iterator over the map inside @a doc.
      *
@@ -43,7 +43,7 @@ class DocumentValueList : public ValueList {
     Xapian::Document::Internal::document_values::const_iterator it;
 
   public:
-    explicit DocumentValueList(const Xapian::Internal::RefCntPtr<Xapian::Document::Internal> & doc_)
+    explicit DocumentValueList(const Xapian::Internal::intrusive_ptr<Xapian::Document::Internal> & doc_)
 	: doc(doc_), it(doc->values.end()) { }
 
     Xapian::docid get_docid() const;
