@@ -2,7 +2,7 @@
  *
  * Copyright 1999,2000,2001 BrightStation PLC
  * Copyright 2002 Ananova Ltd
- * Copyright 2003,2004,2006,2007,2008,2009,2011,2014 Olly Betts
+ * Copyright 2003,2004,2006,2007,2008,2009,2011,2013,2014 Olly Betts
  * Copyright 2009 Lemur Consulting Ltd
  *
  * This program is free software; you can redistribute it and/or
@@ -25,11 +25,12 @@
 
 #include <xapian/document.h>
 
-#include "document.h"
+#include "backends/document.h"
 #include "documentvaluelist.h"
 #include "maptermlist.h"
-#include "serialise.h"
+#include "net/serialise.h"
 #include "str.h"
+#include "unicode/description_append.h"
 
 #include <xapian/error.h>
 #include <xapian/types.h>
@@ -92,7 +93,7 @@ Document::~Document()
 string
 Document::get_description() const
 {
-    return "Document(" + internal->get_description() + ")";
+    return internal->get_description();
 }
 
 void
@@ -242,7 +243,7 @@ void
 OmDocumentTerm::remove_position(Xapian::termpos tpos)
 {
     LOGCALL_VOID(DB, "OmDocumentTerm::remove_position", tpos);
-    
+
     // Search for the position the term occurs at.  Use binary chop to
     // search, since this is a sorted list.
     vector<Xapian::termpos>::iterator i;
@@ -278,13 +279,14 @@ Xapian::Document::Internal::get_value(Xapian::valueno slot) const
     if (!database.get()) return string();
     return do_get_value(slot);
 }
-	
+
 string
 Xapian::Document::Internal::get_data() const
 {
-    if (data_here) return data;
-    if (!database.get()) return string();
-    return do_get_data();
+    LOGCALL(DB, string, "Xapian::Document::Internal::get_data", NO_ARGS);
+    if (data_here) RETURN(data);
+    if (!database.get()) RETURN(string());
+    RETURN(do_get_data());
 }
 
 void
@@ -375,14 +377,14 @@ Xapian::Document::Internal::add_term(const string & tname, Xapian::termcount wdf
 void
 Xapian::Document::Internal::remove_posting(const string & tname,
 					   Xapian::termpos tpos,
-					   Xapian::termcount wdfdec)	
+					   Xapian::termcount wdfdec)
 {
     need_terms();
 
     map<string, OmDocumentTerm>::iterator i;
     i = terms.find(tname);
     if (i == terms.end()) {
-	throw Xapian::InvalidArgumentError("Term `" + tname +
+	throw Xapian::InvalidArgumentError("Term '" + tname +
 		"' is not present in document, in "
 		"Xapian::Document::Internal::remove_posting()");
     }
@@ -398,14 +400,14 @@ Xapian::Document::Internal::remove_term(const string & tname)
     map<string, OmDocumentTerm>::iterator i;
     i = terms.find(tname);
     if (i == terms.end()) {
-	throw Xapian::InvalidArgumentError("Term `" + tname +
+	throw Xapian::InvalidArgumentError("Term '" + tname +
 		"' is not present in document, in "
 		"Xapian::Document::Internal::remove_term()");
     }
     positions_modified = !i->second.positions.empty();
     terms.erase(i);
 }
-	
+
 void
 Xapian::Document::Internal::clear_terms()
 {
@@ -437,9 +439,8 @@ Xapian::Document::Internal::need_terms() const
 	Xapian::TermIterator tend(NULL);
 	for ( ; t != tend; ++t) {
 	    Xapian::PositionIterator p = t.positionlist_begin();
-	    Xapian::PositionIterator pend = t.positionlist_end();
 	    OmDocumentTerm term(t.get_wdf());
-	    for ( ; p != pend; ++p) {
+	    for ( ; p != t.positionlist_end(); ++p) {
 		term.add_position(*p);
 	    }
 	    terms.insert(make_pair(*t, term));
@@ -460,29 +461,39 @@ Xapian::Document::Internal::values_count() const
 string
 Xapian::Document::Internal::get_description() const
 {
-    string description = "Xapian::Document::Internal(";
+    string desc = "Document(";
 
-    if (data_here) description += "data=`" + data + "'";
+    // description_append ?
+    if (data_here) {
+	desc += "data='";
+	description_append(desc, data);
+	desc += "'";
+    }
 
     if (values_here) {
-	if (data_here) description += ", ";
-	description += "values[" + str(values.size()) + "]";
+	if (data_here) desc += ", ";
+	desc += "values[";
+	desc += str(values.size());
+	desc += ']';
     }
 
     if (terms_here) {
-	if (data_here || values_here) description += ", ";
-	description += "terms[" + str(terms.size()) + "]";
+	if (data_here || values_here) desc += ", ";
+	desc += "terms[";
+	desc += str(terms.size());
+	desc += ']';
     }
 
     if (database.get()) {
-	if (data_here || values_here || terms_here) description += ", ";
-	description += "doc=";
-	description += "?"; // do_get_description(); ?
+	if (data_here || values_here || terms_here) desc += ", ";
+	// database->get_description() if/when that returns a non-generic
+	// result.
+	desc += "db:yes";
     }
 
-    description += ')';
+    desc += ')';
 
-    return description;
+    return desc;
 }
 
 void
