@@ -1,7 +1,7 @@
 /** @file valueiterator.cc
  *  @brief Class for iterating over document values.
  */
-/* Copyright (C) 2008,2009,2013 Olly Betts
+/* Copyright (C) 2008,2009,2011,2013 Olly Betts
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,47 +24,64 @@
 
 #include "debuglog.h"
 #include "omassert.h"
-#include "valuelist.h"
+#include "backends/valuelist.h"
 
 using namespace std;
 
 namespace Xapian {
 
-ValueIterator::ValueIterator() : internal(NULL) { }
-
-ValueIterator::~ValueIterator() { }
+void
+ValueIterator::decref()
+{
+    Assert(internal);
+    if (--internal->_refs == 0)
+	delete internal;
+}
 
 ValueIterator::ValueIterator(Internal *internal_) : internal(internal_)
 {
-    internal->next();
-    if (internal->at_end()) internal = NULL;
+    LOGCALL_CTOR(API, "ValueIterator", internal_);
+    Assert(internal);
+    ++internal->_refs;
+    try {
+	internal->next();
+    } catch (...) {
+	// The destructor only runs if the constructor completes, so we have to
+	// take care of cleaning up for ourselves here.
+	decref();
+	throw;
+    }
+    if (internal->at_end()) {
+	decref();
+	internal = NULL;
+    }
 }
 
 ValueIterator::ValueIterator(const ValueIterator & o)
-    : internal(o.internal) { }
-
-ValueIterator::ValueIterator(const ValueIteratorEnd_ &)
-    : internal(NULL) { }
+    : internal(o.internal)
+{
+    LOGCALL_CTOR(API, "ValueIterator", o);
+    if (internal)
+	++internal->_refs;
+}
 
 ValueIterator &
 ValueIterator::operator=(const ValueIterator & o)
 {
+    LOGCALL(API, ValueIterator &, "ValueIterator::operator=", o);
+    if (o.internal)
+	++o.internal->_refs;
+    if (internal)
+	decref();
     internal = o.internal;
-    return *this;
-}
-
-ValueIterator &
-ValueIterator::operator=(const ValueIteratorEnd_ &)
-{
-    internal = NULL;
-    return *this;
+    RETURN(*this);
 }
 
 string
 ValueIterator::operator*() const
 {
     LOGCALL(API, string, "ValueIterator::operator*", NO_ARGS);
-    Assert(internal.get());
+    Assert(internal);
     RETURN(internal->get_value());
 }
 
@@ -72,9 +89,12 @@ ValueIterator &
 ValueIterator::operator++()
 {
     LOGCALL(API, ValueIterator &, "ValueIterator::operator++", NO_ARGS);
-    Assert(internal.get());
+    Assert(internal);
     internal->next();
-    if (internal->at_end()) internal = NULL;
+    if (internal->at_end()) {
+	decref();
+	internal = NULL;
+    }
     RETURN(*this);
 }
 
@@ -82,7 +102,7 @@ Xapian::docid
 ValueIterator::get_docid() const
 {
     LOGCALL(API, Xapian::docid, "ValueIterator::get_docid", NO_ARGS);
-    Assert(internal.get());
+    Assert(internal);
     RETURN(internal->get_docid());
 }
 
@@ -90,7 +110,7 @@ Xapian::valueno
 ValueIterator::get_valueno() const
 {
     LOGCALL(API, Xapian::valueno, "ValueIterator::get_valueno", NO_ARGS);
-    Assert(internal.get());
+    Assert(internal);
     RETURN(internal->get_valueno());
 }
 
@@ -98,18 +118,26 @@ void
 ValueIterator::skip_to(Xapian::docid docid_or_slot)
 {
     LOGCALL_VOID(API, "ValueIterator::skip_to", docid_or_slot);
-    if (!internal.get()) return;
-    internal->skip_to(docid_or_slot);
-    if (internal->at_end()) internal = NULL;
+    if (internal) {
+	internal->skip_to(docid_or_slot);
+	if (internal->at_end()) {
+	    decref();
+	    internal = NULL;
+	}
+    }
 }
 
 bool
 ValueIterator::check(Xapian::docid did)
 {
     LOGCALL(API, bool, "ValueIterator::check", did);
-    if (!internal.get()) RETURN(true);
-    if (!internal->check(did)) RETURN(false);
-    if (internal->at_end()) internal = NULL;
+    if (internal) {
+	if (!internal->check(did)) RETURN(false);
+	if (internal->at_end()) {
+	    decref();
+	    internal = NULL;
+	}
+    }
     RETURN(true);
 }
 
@@ -117,7 +145,8 @@ std::string
 ValueIterator::get_description() const
 {
     string desc = "ValueIterator(";
-    if (internal.get()) desc += internal->get_description();
+    if (internal)
+	desc += internal->get_description();
     desc += ')';
     return desc;
 }
