@@ -2,7 +2,7 @@
  * @brief Support class for database replication.
  */
 /* Copyright 2008 Lemur Consulting Ltd
- * Copyright 2009,2010 Olly Betts
+ * Copyright 2009,2010,2011,2012 Olly Betts
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -28,17 +28,14 @@
 #include "xapian/version.h" // For XAPIAN_HAS_XXX_BACKEND.
 
 #include "debuglog.h"
-#include "utils.h"
+#include "filetests.h"
 
-#ifdef XAPIAN_HAS_BRASS_BACKEND
-# include "brass/brass_databasereplicator.h"
+#ifdef XAPIAN_HAS_GLASS_BACKEND
+# include "glass/glass_databasereplicator.h"
 #endif
 #ifdef XAPIAN_HAS_CHERT_BACKEND
 # include "chert/chert_databasereplicator.h"
 #endif
-#ifdef XAPIAN_HAS_FLINT_BACKEND
-# include "flint/flint_databasereplicator.h"
-#endif
 
 using namespace std;
 
@@ -51,7 +48,7 @@ DatabaseReplicator::~DatabaseReplicator()
 DatabaseReplicator *
 DatabaseReplicator::open(const string & path)
 {
-    LOGCALL_STATIC_VOID(DB, "DatabaseReplicator::DatabaseReplicator", path);
+    LOGCALL_STATIC(DB, DatabaseReplicator *, "DatabaseReplicator::open", path);
 
 #ifdef XAPIAN_HAS_CHERT_BACKEND
     if (file_exists(path + "/iamchert")) {
@@ -59,17 +56,19 @@ DatabaseReplicator::open(const string & path)
     }
 #endif
 
-#ifdef XAPIAN_HAS_FLINT_BACKEND
-    if (file_exists(path + "/iamflint")) {
-	return new FlintDatabaseReplicator(path);
+#ifdef XAPIAN_HAS_GLASS_BACKEND
+    if (file_exists(path + "/iamglass")) {
+	return new GlassDatabaseReplicator(path);
     }
 #endif
 
-#ifdef XAPIAN_HAS_BRASS_BACKEND
+    if (file_exists(path + "/iamflint")) {
+	throw FeatureUnavailableError("Flint backend no longer supported");
+    }
+
     if (file_exists(path + "/iambrass")) {
-	return new BrassDatabaseReplicator(path);
+	throw FeatureUnavailableError("Brass backend no longer supported");
     }
-#endif
 
     throw DatabaseOpeningError("Couldn't detect type of database: " + path);
 }
