@@ -130,7 +130,7 @@ class GlassPositionList : public PositionList {
 		   const string & tname);
 
     /// Returns size of position list.
-    Xapian::termcount get_size() const;
+    Xapian::termcount get_approx_size() const;
 
     /** Returns current position.
      *
@@ -140,13 +140,10 @@ class GlassPositionList : public PositionList {
     Xapian::termpos get_position() const;
 
     /// Advance to the next term position in the list.
-    void next();
+    bool next();
 
     /// Advance to the first term position which is at least termpos.
-    void skip_to(Xapian::termpos termpos);
-
-    /// True if we're off the end of the list
-    bool at_end() const;
+    bool skip_to(Xapian::termpos termpos);
 };
 
 #endif /* XAPIAN_HGUARD_GLASS_POSITIONLIST_H */
