@@ -257,7 +257,7 @@ class InMemoryDatabase : public Xapian::Database::Internal {
 
     Xapian::doccount totdocs;
 
-    totlen_t totlen;
+    Xapian::totallength totlen;
 
     bool positions_present;
 
@@ -321,7 +321,7 @@ class InMemoryDatabase : public Xapian::Database::Internal {
 
     Xapian::docid get_lastdocid() const;
 
-    totlen_t get_total_length() const;
+    Xapian::totallength get_total_length() const;
     Xapian::termcount get_doclength(Xapian::docid did) const;
     Xapian::termcount get_unique_terms(Xapian::docid did) const;
 
