@@ -27,7 +27,6 @@
 #include <signal.h>
 
 #include "autoptr.h"
-#include "api/emptypostlist.h"
 #include "backends/inmemory/inmemory_positionlist.h"
 #include "net_postlist.h"
 #include "net_termlist.h"
@@ -403,7 +402,7 @@ RemoteDatabase::get_lastdocid() const
     return lastdocid;
 }
 
-totlen_t
+Xapian::totallength
 RemoteDatabase::get_total_length() const
 {
     if (!cached_stats_valid) update_stats();
