@@ -1,7 +1,7 @@
 /** @file debuglog.h
  * @brief Debug logging macros.
  */
-/* Copyright (C) 2008,2009,2010,2011,2014 Olly Betts
+/* Copyright (C) 2008,2009,2010,2011,2014,2015 Olly Betts
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,9 +21,18 @@
 #ifndef XAPIAN_INCLUDED_DEBUGLOG_H
 #define XAPIAN_INCLUDED_DEBUGLOG_H
 
+// In places where we include library code in non-library contexts, we can't
+// have debug logging enabled, as the support functions aren't visible, so
+// we define XAPIAN_REALLY_NO_DEBUG_LOG there.
+#ifdef XAPIAN_REALLY_NO_DEBUG_LOG
+# ifdef XAPIAN_DEBUG_LOG
+#  undef XAPIAN_DEBUG_LOG
+# endif
+#endif
+
 #ifdef XAPIAN_DEBUG_LOG
 
-#include "output.h"
+#include "output-internal.h"
 #include "pretty.h"
 
 #include <cstring>
@@ -69,12 +78,13 @@ enum debuglog_categories {
     /// Weight calculations.
     DEBUGLOG_CATEGORY_WTCALC = ('W' - '@'),
 
+    /// Query stuff.
+    DEBUGLOG_CATEGORY_QUERY = ('Y' - '@'),
+
     /// Messages which are always logged.
     DEBUGLOG_CATEGORY_ALWAYS = 31
 };
 
-// FIXME: STATIC_ASSERT(DEBUGLOG_CATEGORY_WTCALC < DEBUGLOG_CATEGORY_ALWAYS);
-
 /// Class to actually do the logging.
 class DebugLogger {
     /// Don't allow assignment.
@@ -115,7 +125,7 @@ class DebugLogger {
 	return (categories_mask >> category) & 1;
     }
 
-    /// Log message @msg of category @a category.
+    /// Log message @a msg of category @a category.
     void log_line(debuglog_categories category, const std::string & msg);
 
     void indent() { ++indent_level; }
