@@ -29,7 +29,7 @@
 #ifndef HAVE_EXP10
 # ifdef HAVE___EXP10
 inline double exp10(double x) { return __exp10(x); }
-# elif HAVE_DECL___BUILTIN_EXP10
+# elif defined HAVE___BUILTIN_EXP10
 inline double exp10(double x) { return __builtin_exp10(x); }
 # else
 inline double exp10(double x) { return std::pow(10.0, x); }
