@@ -1,7 +1,7 @@
 /** @file pack.h
  * @brief Pack types into strings and unpack them again.
  */
-/* Copyright (C) 2009 Olly Betts
+/* Copyright (C) 2009,2015,2016 Olly Betts
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -128,6 +128,8 @@ unpack_uint_last(const char ** p, const char * end, U * result)
 }
 
 /** Append an encoded unsigned integer to a string, preserving the sort order.
+ *
+ *  [Chert variant]
  *
  *  The appended string data will sort in the same order as the unsigned
  *  integer being encoded.
@@ -141,11 +143,15 @@ unpack_uint_last(const char ** p, const char * end, U * result)
  */
 template<class U>
 inline void
-pack_uint_preserving_sort(std::string & s, U value)
+C_pack_uint_preserving_sort(std::string & s, U value)
 {
     // Check U is an unsigned type.
     STATIC_ASSERT_UNSIGNED_TYPE(U);
-    STATIC_ASSERT(sizeof(U) <= SORTABLE_UINT_MAX_BYTES);
+#if 0
+    // FIXME: Doesn't work with 64-bit Xapian::docid, etc.
+    static_assert(sizeof(U) <= SORTABLE_UINT_MAX_BYTES,
+		  "Template type U too wide for database format");
+#endif
 
     char tmp[sizeof(U) + 1];
     char * p = tmp + sizeof(tmp);
@@ -158,12 +164,15 @@ pack_uint_preserving_sort(std::string & s, U value)
     unsigned char len = static_cast<unsigned char>(tmp + sizeof(tmp) - p);
     *--p = char((len - 1) << (8 - SORTABLE_UINT_LOG2_MAX_BYTES) | value);
     s.append(p, len + 1);
+    Assert(s[0] != '\xff');
 }
 
 /** Decode an "sort preserved" unsigned integer from a string.
+ *
+ *  [Chert variant]
  *
  *  The unsigned integer must have been encoded with
- *  pack_uint_preserving_sort().
+ *  C_pack_uint_preserving_sort().
  *
  *  @param p	    Pointer to pointer to the current position in the string.
  *  @param end	    Pointer to the end of the string.
@@ -171,11 +180,12 @@ pack_uint_preserving_sort(std::string & s, U value)
  */
 template<class U>
 inline bool
-unpack_uint_preserving_sort(const char ** p, const char * end, U * result)
+C_unpack_uint_preserving_sort(const char ** p, const char * end, U * result)
 {
     // Check U is an unsigned type.
     STATIC_ASSERT_UNSIGNED_TYPE(U);
-    STATIC_ASSERT(sizeof(U) < 256);
+    static_assert(sizeof(U) < 256,
+		  "Template type U too wide for database format");
     Assert(result);
 
     const char * ptr = *p;
@@ -208,6 +218,142 @@ unpack_uint_preserving_sort(const char ** p, const char * end, U * result)
     return true;
 }
 
+#if HAVE_DECL___BUILTIN_CLZ && \
+    HAVE_DECL___BUILTIN_CLZL && \
+    HAVE_DECL___BUILTIN_CLZLL
+inline int do_clz(unsigned value) { return __builtin_clz(value); }
+
+inline int do_clz(unsigned long value) { return __builtin_clzl(value); }
+
+inline int do_clz(unsigned long long value) { return __builtin_clzll(value); }
+
+# define HAVE_DO_CLZ
+#endif
+
+/** Append an encoded unsigned integer to a string, preserving the sort order.
+ *
+ *  [Glass and newer variant]
+ *
+ *  The appended string data will sort in the same order as the unsigned
+ *  integer being encoded.
+ *
+ *  Note that the first byte of the encoding will never be \xff, so it is
+ *  safe to store the result of this function immediately after the result of
+ *  pack_string_preserving_sort().
+ *
+ *  @param s		The string to append to.
+ *  @param value	The unsigned integer to encode.
+ */
+template<class U>
+inline void
+pack_uint_preserving_sort(std::string & s, U value)
+{
+    // Check U is an unsigned type.
+    STATIC_ASSERT_UNSIGNED_TYPE(U);
+    static_assert(sizeof(U) <= 8,
+		  "Template type U too wide for database format");
+    // The clz() functions are undefined for 0, so handle the smallest band
+    // as a special case.
+    if (value < 0x8000) {
+	s.resize(s.size() + 2);
+	s[s.size() - 2] = static_cast<unsigned char>(value >> 8);
+	Assert(s[s.size() - 2] != '\xff');
+	s[s.size() - 1] = static_cast<unsigned char>(value);
+	return;
+    }
+
+#ifdef HAVE_DO_CLZ
+    size_t len = ((sizeof(U) * 8 + 5) - do_clz(value)) / 7;
+#else
+    size_t len = 3;
+    for (U x = value >> 22; x; x >>= 7) ++len;
+#endif
+    unsigned mask = 0xff << (10 - len);
+
+    s.resize(s.size() + len);
+    for (size_t i = 1; i != len; ++i) {
+	s[s.size() - i] = static_cast<unsigned char>(value);
+	value >>= 8;
+    }
+
+    s[s.size() - len] = static_cast<unsigned char>(value | mask);
+    Assert(s[s.size() - len] != '\xff');
+
+    AssertRel(len, >, 2);
+    AssertRel(len, <=, 9);
+}
+
+/** Decode an "sort preserved" unsigned integer from a string.
+ *
+ *  [Glass and newer variant]
+ *
+ *  The unsigned integer must have been encoded with
+ *  pack_uint_preserving_sort().
+ *
+ *  @param p	    Pointer to pointer to the current position in the string.
+ *  @param end	    Pointer to the end of the string.
+ *  @param result   Where to store the result.
+ */
+template<class U>
+inline bool
+unpack_uint_preserving_sort(const char ** p, const char * end, U * result)
+{
+    // Check U is an unsigned type.
+    STATIC_ASSERT_UNSIGNED_TYPE(U);
+    static_assert(sizeof(U) <= 8,
+		  "Template type U too wide for database format");
+    Assert(result);
+
+    const char * ptr = *p;
+    Assert(ptr);
+
+    if (rare(ptr == end)) {
+	return false;
+    }
+
+    unsigned char len_byte = static_cast<unsigned char>(*ptr++);
+    if (len_byte < 0x80) {
+	*result = (U(len_byte) << 8) | static_cast<unsigned char>(*ptr++);
+	*p = ptr;
+	return true;
+    }
+
+    if (len_byte == 0xff) {
+	return false;
+    }
+
+    // len is how many bytes there are after the length byte.
+#ifdef HAVE_DO_CLZ
+    size_t len = do_clz(len_byte ^ 0xffu) + 9 - sizeof(unsigned) * 8;
+#else
+    size_t len = 2;
+    for (unsigned char m = 0x40; len_byte & m; m >>= 1) ++len;
+#endif
+    if (rare(size_t(end - ptr) < len)) {
+	return false;
+    }
+    unsigned mask = 0xff << (9 - len);
+    len_byte &= ~mask;
+
+    // Check for overflow.
+    if (rare(len > int(sizeof(U)))) return false;
+    if (sizeof(U) != 8) {
+	// Need to check the top byte too.
+	if (rare(len == int(sizeof(U)) && len_byte != 0)) return false;
+    }
+
+    end = ptr + len;
+    *p = end;
+
+    U r = len_byte;
+    while (ptr != end) {
+	r = (r << 8) | U(static_cast<unsigned char>(*ptr++));
+    }
+    *result = r;
+
+    return true;
+}
+
 /** Append an encoded unsigned integer to a string.
  *
  *  @param s		The string to append to.
@@ -433,6 +579,34 @@ pack_chert_postlist_key(const std::string &term)
 
 inline std::string
 pack_chert_postlist_key(const std::string &term, Xapian::docid did)
+{
+    // Special case for doclen lists.
+    if (term.empty()) {
+	std::string key("\x00\xe0", 2);
+	C_pack_uint_preserving_sort(key, did);
+	return key;
+    }
+
+    std::string key;
+    pack_string_preserving_sort(key, term);
+    C_pack_uint_preserving_sort(key, did);
+    return key;
+}
+
+inline std::string
+pack_glass_postlist_key(const std::string &term)
+{
+    // Special case for doclen lists.
+    if (term.empty())
+	return std::string("\x00\xe0", 2);
+
+    std::string key;
+    pack_string_preserving_sort(key, term, true);
+    return key;
+}
+
+inline std::string
+pack_glass_postlist_key(const std::string &term, Xapian::docid did)
 {
     // Special case for doclen lists.
     if (term.empty()) {
@@ -447,16 +621,4 @@ pack_chert_postlist_key(const std::string &term, Xapian::docid did)
     return key;
 }
 
-inline std::string
-pack_brass_postlist_key(const std::string &term)
-{
-    return pack_chert_postlist_key(term);
-}
-
-inline std::string
-pack_brass_postlist_key(const std::string &term, Xapian::docid did)
-{
-    return pack_chert_postlist_key(term, did);
-}
-
 #endif // XAPIAN_INCLUDED_PACK_H
