@@ -36,7 +36,7 @@ struct PrettyOStream {
     S & os;
 
     PrettyOStream(S & os_) : os(os_) { }
-    template <typename T> PrettyOStream & operator|(const T & t){
+    template <typename T> PrettyOStream & operator|(const T & t) {
 	os << ", ";
 	return *this << t;
     }
@@ -298,18 +298,18 @@ XAPIAN_PRETTY_AS_CLASSNAME(Xapian::LatLongMetric)
 XAPIAN_PRETTY_AS_CLASSNAME(Xapian::MatchDecider)
 XAPIAN_PRETTY_AS_CLASSNAME(Xapian::Registry)
 XAPIAN_PRETTY_AS_CLASSNAME(Xapian::Weight)
-XAPIAN_PRETTY_AS_CLASSNAME(Xapian::Internal::AndContext);
-XAPIAN_PRETTY_AS_CLASSNAME(Xapian::Internal::ExpandStats);
-XAPIAN_PRETTY_AS_CLASSNAME(Xapian::Internal::ExpandWeight);
-XAPIAN_PRETTY_AS_CLASSNAME(Xapian::Internal::OrContext);
-XAPIAN_PRETTY_AS_CLASSNAME(ChertCursor);
-XAPIAN_PRETTY_AS_CLASSNAME(ChertDatabase);
-XAPIAN_PRETTY_AS_CLASSNAME(ChertTable);
-XAPIAN_PRETTY_AS_CLASSNAME(Glass::RootInfo);
-XAPIAN_PRETTY_AS_CLASSNAME(GlassCursor);
-XAPIAN_PRETTY_AS_CLASSNAME(GlassFreeListChecker);
-XAPIAN_PRETTY_AS_CLASSNAME(GlassDatabase);
-XAPIAN_PRETTY_AS_CLASSNAME(GlassTable);
+XAPIAN_PRETTY_AS_CLASSNAME(Xapian::Internal::AndContext)
+XAPIAN_PRETTY_AS_CLASSNAME(Xapian::Internal::ExpandStats)
+XAPIAN_PRETTY_AS_CLASSNAME(Xapian::Internal::ExpandWeight)
+XAPIAN_PRETTY_AS_CLASSNAME(Xapian::Internal::OrContext)
+XAPIAN_PRETTY_AS_CLASSNAME(ChertCursor)
+XAPIAN_PRETTY_AS_CLASSNAME(ChertDatabase)
+XAPIAN_PRETTY_AS_CLASSNAME(ChertTable)
+XAPIAN_PRETTY_AS_CLASSNAME(Glass::RootInfo)
+XAPIAN_PRETTY_AS_CLASSNAME(GlassCursor)
+XAPIAN_PRETTY_AS_CLASSNAME(GlassFreeListChecker)
+XAPIAN_PRETTY_AS_CLASSNAME(GlassDatabase)
+XAPIAN_PRETTY_AS_CLASSNAME(GlassTable)
 
 template<class S>
 inline PrettyOStream<S> &
