@@ -1,7 +1,7 @@
 /** @file remoteprotocol.h
  *  @brief Remote protocol version and message numbers
  */
-/* Copyright (C) 2006,2007,2008,2009,2010,2015 Olly Betts
+/* Copyright (C) 2006,2007,2008,2009,2010,2011,2013,2014,2015 Olly Betts
  * Copyright (C) 2007,2010 Lemur Consulting Ltd
  *
  * This program is free software; you can redistribute it and/or modify
@@ -45,9 +45,12 @@
 // 34: 1.1.4 Support for metadata over with remote databases.
 // 35: 1.1.5 Support for add_spelling() and remove_spelling().
 // 35.1: 1.2.4 Support for metadata_keys_begin().
-// 35.2: 1.2.21 Sort keys in serialised MSet.
-#define XAPIAN_REMOTE_PROTOCOL_MAJOR_VERSION 35
-#define XAPIAN_REMOTE_PROTOCOL_MINOR_VERSION 2
+// 36: 1.3.0 REPLY_UPDATE and REPLY_GREETING merged, and more...
+// 37: 1.3.1 Prefix-compress termlists.
+// 38: 1.3.2 Stats serialisation now includes collection freq, and more...
+// 39: 1.3.3 New query operator OP_WILDCARD; sort keys in serialised MSet.
+#define XAPIAN_REMOTE_PROTOCOL_MAJOR_VERSION 39
+#define XAPIAN_REMOTE_PROTOCOL_MINOR_VERSION 0
 
 /** Message types (client -> server).
  *
@@ -84,13 +87,14 @@ enum message_type {
     MSG_GETMSET,		// Get MSet
     MSG_SHUTDOWN,		// Shutdown
     MSG_METADATAKEYLIST,	// Iterator for metadata keys
-    MSG_QUERY_NEW,		// Run Query (protocol 35.2 version)
+    MSG_FREQS,			// Get termfreq and collfreq
+    MSG_UNIQUETERMS,		// Get number of unique terms in doc
     MSG_MAX
 };
 
 /// Reply types (server -> client).
 enum reply_type {
-    REPLY_GREETING,		// Greeting
+    REPLY_UPDATE,		// Updated database stats
     REPLY_EXCEPTION,		// Exception
     REPLY_DONE,			// Done sending list
     REPLY_ALLTERMS,		// All Terms
@@ -106,13 +110,13 @@ enum reply_type {
     REPLY_POSITIONLIST,		// Get PositionList
     REPLY_POSTLISTSTART,	// Start of a postlist
     REPLY_POSTLISTITEM,		// Item in body of a postlist
-    REPLY_UPDATE,		// Get Updated DocCount and AvLength
     REPLY_VALUE,		// Document Value
     REPLY_ADDDOCUMENT,		// Add Document
     REPLY_RESULTS,		// Results (MSet)
     REPLY_METADATA,		// Metadata
     REPLY_METADATAKEYLIST,	// Iterator for metadata keys
-    REPLY_RESULTS_NEW,		// Results (MSet) (protocol 35.2 version)
+    REPLY_FREQS,		// Get termfreq and collfreq
+    REPLY_UNIQUETERMS,		// Get number of unique terms in doc
     REPLY_MAX
 };
 
