@@ -1,7 +1,7 @@
 /** @file queryparser.h
  * @brief parsing a user query string to build a Xapian::Query object
  */
-/* Copyright (C) 2005,2006,2007,2008,2009,2010,2011,2012,2013,2014,2015,2016 Olly Betts
+/* Copyright (C) 2005,2006,2007,2008,2009,2010,2011,2012,2013,2014,2015,2016,2017 Olly Betts
  * Copyright (C) 2010 Adam Sjøgren
  *
  * This program is free software; you can redistribute it and/or
@@ -28,6 +28,7 @@
 #endif
 
 #include <xapian/attributes.h>
+#include <xapian/deprecated.h>
 #include <xapian/intrusive_ptr.h>
 #include <xapian/query.h>
 #include <xapian/termiterator.h>
@@ -66,11 +67,25 @@ class XAPIAN_VISIBILITY_DEFAULT Stopper
     /// Return a string describing this object.
     virtual std::string get_description() const;
 
+    /** Start reference counting this object.
+     *
+     *  You can hand ownership of a dynamically allocated Stopper
+     *  object to Xapian by calling release() and then passing the object to a
+     *  Xapian method.  Xapian will arrange to delete the object once it is no
+     *  longer required.
+     */
     Stopper * release() {
 	opt_intrusive_base::release();
 	return this;
     }
 
+    /** Start reference counting this object.
+     *
+     *  You can hand ownership of a dynamically allocated Stopper
+     *  object to Xapian by calling release() and then passing the object to a
+     *  Xapian method.  Xapian will arrange to delete the object once it is no
+     *  longer required.
+     */
     const Stopper * release() const {
 	opt_intrusive_base::release();
 	return this;
@@ -89,8 +104,8 @@ class XAPIAN_VISIBILITY_DEFAULT SimpleStopper : public Stopper {
      *
      * Xapian includes stop list files for many languages. You can initialise from a file like that:
      * @code
-     * ifstream inFile ("stopwords/english/stop.txt");
-     * Xapian::SimplerStopper stopper(istream_iterator<string>(inFile), istream_iterator<string>());
+     * ifstream words("stopwords/english/stop.txt");
+     * Xapian::SimplerStopper stopper(istream_iterator<string>(words), istream_iterator<string>());
      * @endcode
      *
      */
@@ -123,10 +138,26 @@ class XAPIAN_VISIBILITY_DEFAULT RangeProcessor
     RangeProcessor(const RangeProcessor &);
 
   protected:
+    /** The value slot to process.
+     *
+     *  If this range processor isn't value-based, it can ignore this member.
+     */
     Xapian::valueno slot;
 
+    /** The prefix (or suffix with RP_SUFFIX) string to look for. */
     std::string str;
 
+    /** Flags.
+     *
+     *  Bitwise-or (| in C++) of zero or more of the following:
+     *  * Xapian::RP_SUFFIX - require @a str as a suffix
+     *    instead of a prefix.
+     *  * Xapian::RP_REPEATED - optionally allow @a str
+     *    on both ends of the range - e.g. $1..$10 or
+     *    5m..50m.  By default a prefix is only checked for on
+     *    the start (e.g. date:1/1/1980..31/12/1989), and a
+     *    suffix only on the end (e.g. 2..12kg).
+     */
     unsigned flags;
 
   public:
@@ -140,7 +171,7 @@ class XAPIAN_VISIBILITY_DEFAULT RangeProcessor
      *			to this range (as a prefix by default, or as a suffix
      *			if flags Xapian::RP_SUFFIX is specified).
      *  @param flags_	Zero or more of the following flags, combined with
-     *			bitwise-or:
+     *			bitwise-or (| in C++):
      *			 * Xapian::RP_SUFFIX - require @a str_ as a suffix
      *			   instead of a prefix.
      *			 * Xapian::RP_REPEATED - optionally allow @a str_
@@ -149,17 +180,24 @@ class XAPIAN_VISIBILITY_DEFAULT RangeProcessor
      *			   the start (e.g. date:1/1/1980..31/12/1989), and a
      *			   suffix only on the end (e.g. 2..12kg).
      */
-    RangeProcessor(Xapian::valueno slot_,
-		   const std::string& str_ = std::string(),
-		   unsigned flags_ = 0)
+    explicit RangeProcessor(Xapian::valueno slot_,
+			    const std::string& str_ = std::string(),
+			    unsigned flags_ = 0)
 	: slot(slot_), str(str_), flags(flags_) { }
 
     /// Destructor.
     virtual ~RangeProcessor();
 
+    /** Check prefix/suffix on range.
+     *
+     *  If they match, remove the prefix/suffix and then call operator()()
+     *  to try to handle the range.
+     */
     Xapian::Query check_range(const std::string& b, const std::string& e);
 
     /** Check for a valid range of this type.
+     *
+     *  Override this method to implement your own range handling.
      *
      *  @param begin	The start of the range as specified in the query string
      *			by the user.
@@ -172,11 +210,25 @@ class XAPIAN_VISIBILITY_DEFAULT RangeProcessor
     virtual Xapian::Query
 	operator()(const std::string &begin, const std::string &end);
 
+    /** Start reference counting this object.
+     *
+     *  You can hand ownership of a dynamically allocated RangeProcessor
+     *  object to Xapian by calling release() and then passing the object to a
+     *  Xapian method.  Xapian will arrange to delete the object once it is no
+     *  longer required.
+     */
     RangeProcessor * release() {
 	opt_intrusive_base::release();
 	return this;
     }
 
+    /** Start reference counting this object.
+     *
+     *  You can hand ownership of a dynamically allocated RangeProcessor
+     *  object to Xapian by calling release() and then passing the object to a
+     *  Xapian method.  Xapian will arrange to delete the object once it is no
+     *  longer required.
+     */
     const RangeProcessor * release() const {
 	opt_intrusive_base::release();
 	return this;
@@ -369,11 +421,25 @@ class XAPIAN_VISIBILITY_DEFAULT ValueRangeProcessor
      */
     virtual Xapian::valueno operator()(std::string &begin, std::string &end) = 0;
 
+    /** Start reference counting this object.
+     *
+     *  You can hand ownership of a dynamically allocated ValueRangeProcessor
+     *  object to Xapian by calling release() and then passing the object to a
+     *  Xapian method.  Xapian will arrange to delete the object once it is no
+     *  longer required.
+     */
     ValueRangeProcessor * release() {
 	opt_intrusive_base::release();
 	return this;
     }
 
+    /** Start reference counting this object.
+     *
+     *  You can hand ownership of a dynamically allocated ValueRangeProcessor
+     *  object to Xapian by calling release() and then passing the object to a
+     *  Xapian method.  Xapian will arrange to delete the object once it is no
+     *  longer required.
+     */
     const ValueRangeProcessor * release() const {
 	opt_intrusive_base::release();
 	return this;
@@ -388,10 +454,13 @@ class XAPIAN_VISIBILITY_DEFAULT ValueRangeProcessor
  */
 class XAPIAN_DEPRECATED_CLASS_EX XAPIAN_VISIBILITY_DEFAULT StringValueRangeProcessor : public ValueRangeProcessor {
   protected:
+    /** The value slot to process. */
     Xapian::valueno valno;
 
+    /** Whether to look for @a str as a prefix or suffix. */
     bool prefix;
 
+    /** The prefix (or suffix if prefix==false) string to look for. */
     std::string str;
 
   public:
@@ -669,11 +738,25 @@ class XAPIAN_VISIBILITY_DEFAULT FieldProcessor
      */
     virtual Xapian::Query operator()(const std::string &str) = 0;
 
+    /** Start reference counting this object.
+     *
+     *  You can hand ownership of a dynamically allocated FieldProcessor
+     *  object to Xapian by calling release() and then passing the object to a
+     *  Xapian method.  Xapian will arrange to delete the object once it is no
+     *  longer required.
+     */
     FieldProcessor * release() {
 	opt_intrusive_base::release();
 	return this;
     }
 
+    /** Start reference counting this object.
+     *
+     *  You can hand ownership of a dynamically allocated FieldProcessor
+     *  object to Xapian by calling release() and then passing the object to a
+     *  Xapian method.  Xapian will arrange to delete the object once it is no
+     *  longer required.
+     */
     const FieldProcessor * release() const {
 	opt_intrusive_base::release();
 	return this;
@@ -867,8 +950,8 @@ class XAPIAN_VISIBILITY_DEFAULT QueryParser {
      *
      *				The most useful values for this are OP_OR (the
      *				default) and OP_AND.  OP_NEAR, OP_PHRASE,
-     *				OP_ELITE_SET and OP_SYNONYM are also permitted.
-     *				Passing other values will result in
+     *				OP_ELITE_SET, OP_SYNONYM and OP_MAX are also
+     *				permitted.  Passing other values will result in
      *				InvalidArgumentError being thrown.
      */
     void set_default_op(Query::op default_op);
@@ -907,6 +990,8 @@ class XAPIAN_VISIBILITY_DEFAULT QueryParser {
      *  @param flags	What to set the limit for (default:
      *			FLAG_WILDCARD|FLAG_PARTIAL, setting the limit for both
      *			wildcards and partial terms).
+     *
+     *  @since 1.3.3
      */
     void set_max_expansion(Xapian::termcount max_expansion,
 			   int max_type = Xapian::Query::WILDCARD_LIMIT_ERROR,
@@ -929,7 +1014,7 @@ class XAPIAN_VISIBILITY_DEFAULT QueryParser {
     /** Parse a query.
      *
      *  @param query_string  A free-text query as entered by a user
-     *  @param flags         Zero or more Query::feature_flag specifying
+     *  @param flags         Zero or more QueryParser::feature_flag specifying
      *		what features the QueryParser should support.  Combine
      *		multiple values with bitwise-or (|) (default FLAG_DEFAULT).
      *	@param default_prefix  The default term prefix to use (default none).
@@ -1054,6 +1139,22 @@ class XAPIAN_VISIBILITY_DEFAULT QueryParser {
     void add_boolean_prefix(const std::string &field, const std::string &prefix,
 			    const std::string* grouping = NULL);
 
+    /** Add a boolean term prefix allowing the user to restrict a
+     *  search with a boolean filter specified in the free text query.
+     *
+     *  This is an older version of this method - use the version with
+     *  the `grouping` parameter in preference to this one.
+     *
+     *  @param field   The user visible field name
+     *  @param prefix  The term prefix to map this to
+     *  @param exclusive Controls how multiple filters are combined.  If
+     *			true then @a prefix is used as the `grouping` value,
+     *			so terms with the same prefix are combined with OP_OR,
+     *			then the resulting queries are combined with OP_AND.
+     *			If false, then a unique grouping is created for
+     *			each filter (this is sometimes useful when each
+     *			document can have multiple terms with this prefix).
+     */
     void add_boolean_prefix(const std::string &field, const std::string &prefix,
 			    bool exclusive) {
 	if (exclusive) {
@@ -1070,6 +1171,9 @@ class XAPIAN_VISIBILITY_DEFAULT QueryParser {
 			    const std::string* grouping = NULL);
 
     /** Register a FieldProcessor for a boolean prefix.
+     *
+     *  This is an older version of this method - use the version with
+     *  the `grouping` parameter in preference to this one.
      */
     void add_boolean_prefix(const std::string &field, Xapian::FieldProcessor *proc,
 			    bool exclusive) {
@@ -1081,14 +1185,18 @@ class XAPIAN_VISIBILITY_DEFAULT QueryParser {
 	}
     }
 
-    /// Iterate over terms omitted from the query as stopwords.
+    /// Begin iterator over terms omitted from the query as stopwords.
     TermIterator stoplist_begin() const;
+
+    /// End iterator over terms omitted from the query as stopwords.
     TermIterator XAPIAN_NOTHROW(stoplist_end() const) {
 	return TermIterator();
     }
 
-    /// Iterate over unstemmed forms of the given (stemmed) term used in the query.
+    /// Begin iterator over unstemmed forms of the given stemmed query term.
     TermIterator unstem_begin(const std::string &term) const;
+
+    /// End iterator over unstemmed forms of the given stemmed query term.
     TermIterator XAPIAN_NOTHROW(unstem_end(const std::string &) const) {
 	return TermIterator();
     }
