@@ -2,7 +2,7 @@
  *
  * Copyright 1999,2000,2001 BrightStation PLC
  * Copyright 2001,2002 Ananova Ltd
- * Copyright 2003,2004,2007,2008,2009,2010,2011,2012,2016 Olly Betts
+ * Copyright 2003,2004,2007,2008,2009,2010,2011,2012,2016,2017 Olly Betts
  * Copyright 2009 Lemur Consulting Ltd
  * Copyright 2010 Richard Boulton
  *
@@ -30,6 +30,8 @@
 #include "andmaybepostlist.h"
 #include "omassert.h"
 
+#include "orpositionlist.h"
+
 #include <algorithm>
 
 OrPostList::OrPostList(PostList *left_,
@@ -446,3 +448,10 @@ OrPostList::count_matching_subqs() const
     if (lhead > rhead) RETURN(r->count_matching_subqs());
     RETURN(l->count_matching_subqs() + r->count_matching_subqs());
 }
+
+void
+OrPostList::gather_position_lists(OrPositionList* orposlist)
+{
+    if (lhead <= rhead) l->gather_position_lists(orposlist);
+    if (lhead >= rhead) r->gather_position_lists(orposlist);
+}
