@@ -2,7 +2,7 @@
  * @brief Combine subqueries, weighting as if they are synonyms
  */
 /* Copyright 2007,2009 Lemur Consulting Ltd
- * Copyright 2009,2014 Olly Betts
+ * Copyright 2009,2011,2014,2016 Olly Betts
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -41,10 +41,11 @@ SynonymPostList::set_weight(const Xapian::Weight * wt_)
     wt = wt_;
     want_doclength = wt->get_sumpart_needs_doclength_();
     want_wdf = wt->get_sumpart_needs_wdf_();
+    want_unique_terms = wt->get_sumpart_needs_uniqueterms_();
 }
 
 PostList *
-SynonymPostList::next(Xapian::weight w_min)
+SynonymPostList::next(double w_min)
 {
     LOGCALL(MATCH, PostList *, "SynonymPostList::next", w_min);
     (void)w_min;
@@ -53,7 +54,7 @@ SynonymPostList::next(Xapian::weight w_min)
 }
 
 PostList *
-SynonymPostList::skip_to(Xapian::docid did, Xapian::weight w_min)
+SynonymPostList::skip_to(Xapian::docid did, double w_min)
 {
     LOGCALL(MATCH, PostList *, "SynonymPostList::skip_to", did | w_min);
     (void)w_min;
@@ -61,10 +62,10 @@ SynonymPostList::skip_to(Xapian::docid did, Xapian::weight w_min)
     RETURN(NULL);
 }
 
-Xapian::weight
+double
 SynonymPostList::get_weight() const
 {
-    LOGCALL(MATCH, Xapian::weight, "SynonymPostList::get_weight", NO_ARGS);
+    LOGCALL(MATCH, double, "SynonymPostList::get_weight", NO_ARGS);
     // The wdf returned can be higher than the doclength.  In particular, this
     // can currently occur if the query contains a term more than once; the wdf
     // of each occurrence is added up.
@@ -77,6 +78,9 @@ SynonymPostList::get_weight() const
     // that this is true.  Note that this requires the doclength to be
     // calculated even if the weight object doesn't want it.
 
+    Xapian::termcount unique_terms = 0;
+    if (want_unique_terms)
+	unique_terms = get_unique_terms();
     if (want_wdf) {
 	Xapian::termcount wdf = get_wdf();
 	Xapian::termcount doclen = 0;
@@ -84,24 +88,25 @@ SynonymPostList::get_weight() const
 	    doclen = get_doclength();
 	    if (wdf > doclen) wdf = doclen;
 	}
-	double sumpart = wt->get_sumpart(wdf, doclen);
+	double sumpart = wt->get_sumpart(wdf, doclen, unique_terms);
 	AssertRel(sumpart, <=, wt->get_maxpart());
 	RETURN(sumpart);
     }
-    RETURN(wt->get_sumpart(0, want_doclength ? get_doclength() : 0));
+    Xapian::termcount doclen = want_doclength ? get_doclength() : 0;
+    RETURN(wt->get_sumpart(0, doclen, unique_terms));
 }
 
-Xapian::weight
+double
 SynonymPostList::get_maxweight() const
 {
-    LOGCALL(MATCH, Xapian::weight, "SynonymPostList::get_maxweight", NO_ARGS);
+    LOGCALL(MATCH, double, "SynonymPostList::get_maxweight", NO_ARGS);
     RETURN(wt->get_maxpart());
 }
 
-Xapian::weight
+double
 SynonymPostList::recalc_maxweight()
 {
-    LOGCALL(MATCH, Xapian::weight, "SynonymPostList::recalc_maxweight", NO_ARGS);
+    LOGCALL(MATCH, double, "SynonymPostList::recalc_maxweight", NO_ARGS);
 
     // Call recalc_maxweight on the subtree once, to ensure that the maxweights
     // are initialised.
@@ -126,13 +131,13 @@ SynonymPostList::get_termfreq_min() const {
 
 Xapian::doccount
 SynonymPostList::get_termfreq_est() const {
-    LOGCALL(MATCH, Xapian::doccount, "SynonymPostList::get_termfreq_min", NO_ARGS);
+    LOGCALL(MATCH, Xapian::doccount, "SynonymPostList::get_termfreq_est", NO_ARGS);
     RETURN(subtree->get_termfreq_est());
 }
 
 Xapian::doccount
 SynonymPostList::get_termfreq_max() const {
-    LOGCALL(MATCH, Xapian::doccount, "SynonymPostList::get_termfreq_min", NO_ARGS);
+    LOGCALL(MATCH, Xapian::doccount, "SynonymPostList::get_termfreq_max", NO_ARGS);
     RETURN(subtree->get_termfreq_max());
 }
 
@@ -148,6 +153,12 @@ SynonymPostList::get_doclength() const {
     RETURN(subtree->get_doclength());
 }
 
+Xapian::termcount
+SynonymPostList::get_unique_terms() const {
+    LOGCALL(MATCH, Xapian::termcount, "SynonymPostList::get_unique_terms", NO_ARGS);
+    RETURN(subtree->get_unique_terms());
+}
+
 bool
 SynonymPostList::at_end() const {
     LOGCALL(MATCH, bool, "SynonymPostList::at_end", NO_ARGS);
