@@ -1,7 +1,7 @@
 /** @file valuestreamdocument.cc
  * @brief A document which gets its values from a ValueStreamManager.
  */
-/* Copyright (C) 2009,2014 Olly Betts
+/* Copyright (C) 2009,2011,2014 Olly Betts
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -96,7 +96,7 @@ ValueStreamDocument::do_get_all_values(map<Xapian::valueno, string> & v) const
     if (!doc) {
 	doc = database->open_document(did, true);
     }
-    return doc->do_get_all_values(v);
+    doc->do_get_all_values(v);
 }
 
 string
