@@ -632,7 +632,7 @@ DEFINE_TESTCASE(topercent2, backend) {
     return true;
 }
 
-class myExpandFunctor : public Xapian::ExpandDecider {
+class EvenParityExpandFunctor : public Xapian::ExpandDecider {
     public:
 	bool operator()(const string & tname) const {
 	    unsigned long sum = 0;
@@ -659,7 +659,7 @@ DEFINE_TESTCASE(expandfunctor1, backend) {
     myrset.add_document(*i);
     myrset.add_document(*(++i));
 
-    myExpandFunctor myfunctor;
+    EvenParityExpandFunctor myfunctor;
 
     Xapian::ESet myeset_orig = enquire.get_eset(1000, myrset);
     unsigned int neweset_size = 0;
@@ -1327,7 +1327,7 @@ DEFINE_TESTCASE(eliteset2, backend) {
     TEST_EQUAL(mymset1, mymset2);
     // query lengths differ so mset weights not the same (with some weighting
     // parameters)
-    //test_mset_order_equal(mymset1, mymset2);
+    // test_mset_order_equal(mymset1, mymset2);
 
     return true;
 }
@@ -1712,7 +1712,7 @@ DEFINE_TESTCASE(qlen1, backend) {
     enquire.set_query(q2);
     Xapian::MSet mset2 = enquire.get_mset(0, 2);
     // Check the weights
-    //TEST(mset1.begin().get_weight() < mset2.begin().get_weight());
+    // TEST(mset1.begin().get_weight() < mset2.begin().get_weight());
     TEST(mset1.begin().get_weight() == mset2.begin().get_weight());
     return true;
 }
