@@ -84,20 +84,25 @@ DEFINE_TESTCASE(totaldoclen1, writable) {
     doc2.add_posting("bar", 1, 2000000000);
     db.add_document(doc2);
     TEST_EQUAL(db.get_avlength(), 2000000000);
+    TEST_EQUAL(db.get_total_length(), 4000000000ull);
     db.commit();
     TEST_EQUAL(db.get_avlength(), 2000000000);
+    TEST_EQUAL(db.get_total_length(), 4000000000ull);
     for (int i = 0; i != 20; ++i) {
 	Xapian::Document doc3;
 	doc3.add_posting("count" + str(i), 1, 2000000000);
 	db.add_document(doc3);
     }
     TEST_EQUAL(db.get_avlength(), 2000000000);
+    TEST_EQUAL(db.get_total_length(), 44000000000ull);
     db.commit();
     TEST_EQUAL(db.get_avlength(), 2000000000);
+    TEST_EQUAL(db.get_total_length(), 44000000000ull);
     if (get_dbtype() != "inmemory") {
 	// InMemory doesn't support get_writable_database_as_database().
 	Xapian::Database dbr = get_writable_database_as_database();
 	TEST_EQUAL(dbr.get_avlength(), 2000000000);
+	TEST_EQUAL(dbr.get_total_length(), 44000000000ull);
     }
     return true;
 }
@@ -367,15 +372,18 @@ DEFINE_TESTCASE(testlock1, chert || glass) {
     return true;
 }
 
-struct MyMatchDecider : public Xapian::MatchDecider {
+class CheckMatchDecider : public Xapian::MatchDecider {
     mutable bool called;
 
-    MyMatchDecider() : called(false) { }
+  public:
+    CheckMatchDecider() : called(false) { }
 
     bool operator()(const Xapian::Document &) const {
 	called = true;
 	return true;
     }
+
+    bool was_called() const { return called; }
 };
 
 /// Test Xapian::MatchDecider with remote backend fails.
@@ -384,12 +392,12 @@ DEFINE_TESTCASE(matchdecider4, remote) {
     Xapian::Enquire enquire(db);
     enquire.set_query(Xapian::Query("paragraph"));
 
-    MyMatchDecider mdecider;
+    CheckMatchDecider mdecider;
     Xapian::MSet mset;
 
     TEST_EXCEPTION(Xapian::UnimplementedError,
 	mset = enquire.get_mset(0, 10, NULL, &mdecider));
-    TEST(!mdecider.called);
+    TEST(!mdecider.was_called());
 
     return true;
 }
@@ -727,36 +735,36 @@ DEFINE_TESTCASE(ordecay2, generated) {
 static void
 make_orcheck_db(Xapian::WritableDatabase &db, const string &)
 {
-    static const int t1[6] = {2, 4, 6, 8, 10, 0};
-    static const int t2[11] = {6, 7, 8, 11, 12, 13, 14, 15, 16, 17, 0};
-    static const int t3[11] = {3, 7, 8, 11, 12, 13, 14, 15, 16, 17, 0};
+    static const unsigned t1[] = {2, 4, 6, 8, 10};
+    static const unsigned t2[] = {6, 7, 8, 11, 12, 13, 14, 15, 16, 17};
+    static const unsigned t3[] = {3, 7, 8, 11, 12, 13, 14, 15, 16, 17};
 
     for (unsigned i = 1; i <= 17; ++i) {
 	Xapian::Document doc;
 	db.replace_document(i, doc);
     }
-    for (const int * p = t1; *p != 0; ++p) {
-	Xapian::Document doc(db.get_document(*p));
+    for (unsigned i : t1) {
+	Xapian::Document doc(db.get_document(i));
 	doc.add_term("T1");
-	db.replace_document(*p, doc);
+	db.replace_document(i, doc);
     }
-    for (const int * p = t2; *p != 0; ++p) {
-	Xapian::Document doc(db.get_document(*p));
+    for (unsigned i : t2) {
+	Xapian::Document doc(db.get_document(i));
 	doc.add_term("T2");
-	if (*p < 17) {
+	if (i < 17) {
 	    doc.add_term("T2_lowfreq");
 	}
 	doc.add_value(2, "1");
-	db.replace_document(*p, doc);
+	db.replace_document(i, doc);
     }
-    for (const int * p = t3; *p != 0; ++p) {
-	Xapian::Document doc(db.get_document(*p));
+    for (unsigned i : t3) {
+	Xapian::Document doc(db.get_document(i));
 	doc.add_term("T3");
-	if (*p < 17) {
+	if (i < 17) {
 	    doc.add_term("T3_lowfreq");
 	}
 	doc.add_value(3, "1");
-	db.replace_document(*p, doc);
+	db.replace_document(i, doc);
     }
 }
 
@@ -867,7 +875,7 @@ DEFINE_TESTCASE(msetfirst2, backend) {
     Xapian::Enquire enquire(db);
     enquire.set_query(Xapian::Query("paragraph"));
     Xapian::MSet mset;
-    // Before the fix, this tried to allocated too much memory.
+    // Before the fix, this tried to allocate too much memory.
     mset = enquire.get_mset(0xfffffff0, 1);
     TEST_EQUAL(mset.get_firstitem(), 0xfffffff0);
     // Check that the number of documents gets clamped too.
