@@ -2,7 +2,7 @@
  * @brief tests of MatchSpy usage
  */
 /* Copyright 2007,2009 Lemur Consulting Ltd
- * Copyright 2009,2012 Olly Betts
+ * Copyright 2009,2011,2012,2015 Olly Betts
  * Copyright 2010 Richard Boulton
  *
  * This program is free software; you can redistribute it and/or
@@ -27,12 +27,12 @@
 
 #include <xapian.h>
 
-#include "str.h"
 #include <cmath>
 #include <map>
 #include <vector>
 
 #include "backendmanager.h"
+#include "str.h"
 #include "testsuite.h"
 #include "testutils.h"
 #include "apitest.h"
@@ -47,8 +47,7 @@ class SimpleMatchSpy : public Xapian::MatchSpy {
     // Vector which will be filled with all the document contents seen.
     std::vector<std::string> seen;
 
-    void operator()(const Xapian::Document &doc,
-		    Xapian::weight) {
+    void operator()(const Xapian::Document &doc, double) {
 	// Note that this is not recommended usage of get_data() - you
 	// generally shouldn't call get_data() from inside a MatchSpy, because
 	// it is (likely to be) a slow operation resulting in considerable IO.
@@ -169,7 +168,7 @@ DEFINE_TESTCASE(matchspy2, generated)
     TEST_STRINGS_EQUAL(values_to_repr(spy0), results[0]);
     TEST_STRINGS_EQUAL(values_to_repr(spy1), results[1]);
     TEST_STRINGS_EQUAL(values_to_repr(spy3), results[2]);
-		       
+
     return true;
 }
 
@@ -307,7 +306,7 @@ DEFINE_TESTCASE(matchspy5, backend)
 }
 
 class MySpy : public Xapian::MatchSpy {
-    void operator()(const Xapian::Document &, Xapian::weight) {
+    void operator()(const Xapian::Document &, double) {
     }
 };
 
