@@ -2,7 +2,7 @@
  *
  * Copyright 1999,2000,2001 BrightStation PLC
  * Copyright 2002 Ananova Ltd
- * Copyright 2002,2003,2004,2005,2006,2007,2008,2009,2010,2015,2016 Olly Betts
+ * Copyright 2002,2003,2004,2005,2006,2007,2008,2009,2010,2015,2016,2017 Olly Betts
  * Copyright 2006 Lemur Consulting Ltd
  * Copyright (C) 2016 Vivek Pal
  *
@@ -422,12 +422,24 @@ DEFINE_TESTCASE(nosuchdb1, !backend) {
     // This is a "nodb" test because it doesn't test a particular backend.
     try {
 	Xapian::Database db("NOsuChdaTabASe");
+	FAIL_TEST("Managed to open 'NOsuChdaTabASe'");
     } catch (const Xapian::DatabaseOpeningError & e) {
 	// We don't really require this exact message, but in Xapian <= 1.1.0
 	// this gave "Couldn't detect type of database".
 	TEST_STRINGS_EQUAL(e.get_msg(), "Couldn't stat 'NOsuChdaTabASe'");
     }
 
+    try {
+	Xapian::Database::check("NOsuChdaTabASe");
+	FAIL_TEST("Managed to check 'NOsuChdaTabASe'");
+    } catch (const Xapian::DatabaseOpeningError & e) {
+	// In 1.4.3 and earlier, this threw DatabaseError with the message:
+	// "File is not a Xapian database or database table" (confusing as
+	// there is no file).
+	TEST_STRINGS_EQUAL(e.get_msg(),
+			   "Couldn't find Xapian database or table to check");
+    }
+
     return true;
 }
 
