@@ -2,7 +2,7 @@
  * @brief Tests of serialisation functionality.
  */
 /* Copyright 2009 Lemur Consulting Ltd
- * Copyright 2009,2013 Olly Betts
+ * Copyright 2009,2011,2012,2013 Olly Betts
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -36,6 +36,16 @@ using namespace std;
 // Test for serialising a document
 DEFINE_TESTCASE(serialise_document1, !backend) {
     Xapian::Document doc;
+
+    // Test serialising and unserialising an empty document.
+    Xapian::Document doc1 = Xapian::Document::unserialise(doc.serialise());
+    TEST_EQUAL(doc1.termlist_count(), 0);
+    TEST_EQUAL(doc1.termlist_begin(), doc1.termlist_end());
+    TEST_EQUAL(doc1.values_count(), 0);
+    TEST_EQUAL(doc1.values_begin(), doc1.values_end());
+    TEST_EQUAL(doc1.get_data(), "");
+
+    // Test serialising a document with things in.
     doc.add_term("foo", 2);
     doc.add_posting("foo", 10);
     doc.add_value(1, "bar");
@@ -94,7 +104,7 @@ DEFINE_TESTCASE(serialise_document1, !backend) {
     TEST_EQUAL(k, doc2.values_end());
 
     TEST_EQUAL(doc2.get_data(), "baz");
- 
+
     return true;
 }
 
@@ -163,7 +173,7 @@ DEFINE_TESTCASE(serialise_document2, writable) {
     TEST_EQUAL(k, doc2.values_end());
 
     TEST_EQUAL(doc2.get_data(), "baz");
- 
+
     return true;
 }
 
@@ -172,17 +182,37 @@ DEFINE_TESTCASE(serialise_query1, !backend) {
     Xapian::Query q;
     Xapian::Query q2 = Xapian::Query::unserialise(q.serialise());
     TEST_EQUAL(q.get_description(), q2.get_description());
-    TEST_EQUAL(q.get_description(), "Xapian::Query()");
+    TEST_EQUAL(q.get_description(), "Query()");
 
     q = Xapian::Query("hello");
     q2 = Xapian::Query::unserialise(q.serialise());
     TEST_EQUAL(q.get_description(), q2.get_description());
-    TEST_EQUAL(q.get_description(), "Xapian::Query(hello)");
+    TEST_EQUAL(q.get_description(), "Query(hello)");
 
-    q = Xapian::Query(Xapian::Query::OP_OR, Xapian::Query("hello"), Xapian::Query("world"));
+    q = Xapian::Query("hello", 1, 1);
+    q2 = Xapian::Query::unserialise(q.serialise());
+    // Regression test for fix in Xapian 1.0.0.
+    TEST_EQUAL(q.get_description(), q2.get_description());
+    TEST_EQUAL(q.get_description(), "Query(hello@1)");
+
+    q = Xapian::Query(q.OP_OR, Xapian::Query("hello"), Xapian::Query("world"));
+    q2 = Xapian::Query::unserialise(q.serialise());
+    TEST_EQUAL(q.get_description(), q2.get_description());
+    TEST_EQUAL(q.get_description(), "Query((hello OR world))");
+
+    q = Xapian::Query(q.OP_OR,
+		      Xapian::Query("hello", 1, 1),
+		      Xapian::Query("world", 1, 1));
+    q2 = Xapian::Query::unserialise(q.serialise());
+    TEST_EQUAL(q.get_description(), q2.get_description());
+    TEST_EQUAL(q.get_description(), "Query((hello@1 OR world@1))");
+
+    static const char * phrase[] = { "shaken", "not", "stirred" };
+    q = Xapian::Query(q.OP_PHRASE, phrase, phrase + 3);
+    q = Xapian::Query(q.OP_OR, Xapian::Query("007"), q);
+    q = Xapian::Query(q.OP_SCALE_WEIGHT, q, 3.14);
     q2 = Xapian::Query::unserialise(q.serialise());
     TEST_EQUAL(q.get_description(), q2.get_description());
-    TEST_EQUAL(q.get_description(), "Xapian::Query((hello OR world))");
 
     return true;
 }
@@ -193,20 +223,20 @@ DEFINE_TESTCASE(serialise_query2, !backend) {
     Xapian::Query q(&s1);
     Xapian::Query q2 = Xapian::Query::unserialise(q.serialise());
     TEST_EQUAL(q.get_description(), q2.get_description());
-    TEST_EQUAL(q.get_description(), "Xapian::Query(PostingSource(Xapian::ValueWeightPostingSource(slot=10)))");
+    TEST_EQUAL(q.get_description(), "Query(PostingSource(Xapian::ValueWeightPostingSource(slot=10)))");
 
     Xapian::ValueMapPostingSource s2(11);
     s2.set_default_weight(5.0);
     q = Xapian::Query(&s2);
     q2 = Xapian::Query::unserialise(q.serialise());
     TEST_EQUAL(q.get_description(), q2.get_description());
-    TEST_EQUAL(q.get_description(), "Xapian::Query(PostingSource(Xapian::ValueMapPostingSource(slot=11)))");
+    TEST_EQUAL(q.get_description(), "Query(PostingSource(Xapian::ValueMapPostingSource(slot=11)))");
 
     Xapian::FixedWeightPostingSource s3(5.5);
     q = Xapian::Query(&s3);
     q2 = Xapian::Query::unserialise(q.serialise());
     TEST_EQUAL(q.get_description(), q2.get_description());
-    TEST_EQUAL(q.get_description(), "Xapian::Query(PostingSource(Xapian::FixedWeightPostingSource(wt=5.5)))");
+    TEST_EQUAL(q.get_description(), "Query(PostingSource(Xapian::FixedWeightPostingSource(wt=5.5)))");
 
     return true;
 }
@@ -218,20 +248,20 @@ DEFINE_TESTCASE(serialise_query3, !backend) {
     Xapian::Registry reg;
     Xapian::Query q2 = Xapian::Query::unserialise(q.serialise(), reg);
     TEST_EQUAL(q.get_description(), q2.get_description());
-    TEST_EQUAL(q.get_description(), "Xapian::Query(PostingSource(Xapian::ValueWeightPostingSource(slot=10)))");
+    TEST_EQUAL(q.get_description(), "Query(PostingSource(Xapian::ValueWeightPostingSource(slot=10)))");
 
     Xapian::ValueMapPostingSource s2(11);
     s2.set_default_weight(5.0);
     q = Xapian::Query(&s2);
     q2 = Xapian::Query::unserialise(q.serialise(), reg);
     TEST_EQUAL(q.get_description(), q2.get_description());
-    TEST_EQUAL(q.get_description(), "Xapian::Query(PostingSource(Xapian::ValueMapPostingSource(slot=11)))");
+    TEST_EQUAL(q.get_description(), "Query(PostingSource(Xapian::ValueMapPostingSource(slot=11)))");
 
     Xapian::FixedWeightPostingSource s3(5.5);
     q = Xapian::Query(&s3);
     q2 = Xapian::Query::unserialise(q.serialise(), reg);
     TEST_EQUAL(q.get_description(), q2.get_description());
-    TEST_EQUAL(q.get_description(), "Xapian::Query(PostingSource(Xapian::FixedWeightPostingSource(wt=5.5)))");
+    TEST_EQUAL(q.get_description(), "Query(PostingSource(Xapian::FixedWeightPostingSource(wt=5.5)))");
 
     return true;
 }
@@ -261,7 +291,7 @@ class MyPostingSource2 : public Xapian::ValuePostingSource {
 	return new MyPostingSource2(s);
     }
 
-    Xapian::weight get_weight() const { return 1.0; }
+    double get_weight() const { return 1.0; }
 
     std::string get_description() const {
 	return "MyPostingSource2(" + desc + ")";
@@ -272,12 +302,12 @@ class MyPostingSource2 : public Xapian::ValuePostingSource {
 DEFINE_TESTCASE(serialise_query4, !backend) {
     MyPostingSource2 s1("foo");
     Xapian::Query q(&s1);
-    TEST_EQUAL(q.get_description(), "Xapian::Query(PostingSource(MyPostingSource2(foo)))");
+    TEST_EQUAL(q.get_description(), "Query(PostingSource(MyPostingSource2(foo)))");
     std::string serialised = q.serialise();
 
-    TEST_EXCEPTION(Xapian::InvalidArgumentError, Xapian::Query::unserialise(serialised));
+    TEST_EXCEPTION(Xapian::SerialisationError, Xapian::Query::unserialise(serialised));
     Xapian::Registry reg;
-    TEST_EXCEPTION(Xapian::InvalidArgumentError, Xapian::Query::unserialise(serialised, reg));
+    TEST_EXCEPTION(Xapian::SerialisationError, Xapian::Query::unserialise(serialised, reg));
 
     reg.register_posting_source(s1);
     Xapian::Query q2 = Xapian::Query::unserialise(serialised, reg);
@@ -327,9 +357,9 @@ class ExceptionalPostingSource : public Xapian::PostingSource {
     Xapian::doccount get_termfreq_est() const { return 1; }
     Xapian::doccount get_termfreq_max() const { return 2; }
 
-    void next(Xapian::weight) { }
+    void next(double) { }
 
-    void skip_to(Xapian::docid, Xapian::weight) { }
+    void skip_to(Xapian::docid, double) { }
 
     bool at_end() const { return true; }
     Xapian::docid get_docid() const { return 0; }
@@ -354,7 +384,7 @@ DEFINE_TESTCASE(registry1, !backend) {
 
 	// Either the old entry should be removed, or it should work.
 	const Xapian::PostingSource * p;
-        p = reg.get_posting_source("ExceptionalPostingSource");
+	p = reg.get_posting_source("ExceptionalPostingSource");
 	if (p) {
 	    TEST_EQUAL(p->name(), "ExceptionalPostingSource");
 	}
@@ -383,13 +413,13 @@ class ExceptionalWeight : public Xapian::Weight {
 
     void init(double) { }
 
-    Xapian::weight get_sumpart(Xapian::termcount, Xapian::termcount) const {
+    double get_sumpart(Xapian::termcount, Xapian::termcount, Xapian::termcount) const {
 	return 0;
     }
-    Xapian::weight get_maxpart() const { return 0; }
+    double get_maxpart() const { return 0; }
 
-    Xapian::weight get_sumextra(Xapian::termcount) const { return 0; }
-    Xapian::weight get_maxextra() const { return 0; }
+    double get_sumextra(Xapian::termcount, Xapian::termcount) const { return 0; }
+    double get_maxextra() const { return 0; }
 };
 
 /// Check that exceptions when registering are handled well.
@@ -409,7 +439,7 @@ DEFINE_TESTCASE(registry2, !backend) {
 
 	// Either the old entry should be removed, or it should work.
 	const Xapian::Weight * p;
-        p = reg.get_weighting_scheme("ExceptionalWeight");
+	p = reg.get_weighting_scheme("ExceptionalWeight");
 	if (p) {
 	    TEST_EQUAL(p->name(), "ExceptionalWeight");
 	}
@@ -436,7 +466,7 @@ class ExceptionalMatchSpy : public Xapian::MatchSpy {
 	return new ExceptionalMatchSpy(fail);
     }
 
-    void operator()(const Xapian::Document &, Xapian::weight) {
+    void operator()(const Xapian::Document &, double) {
     }
 };
 
@@ -457,7 +487,7 @@ DEFINE_TESTCASE(registry3, !backend) {
 
 	// Either the old entry should be removed, or it should work.
 	const Xapian::MatchSpy * p;
-        p = reg.get_match_spy("ExceptionalMatchSpy");
+	p = reg.get_match_spy("ExceptionalMatchSpy");
 	if (p) {
 	    TEST_EQUAL(p->name(), "ExceptionalMatchSpy");
 	}
