@@ -124,7 +124,7 @@ DEFINE_TESTCASE(adddoc2, writable) {
     TEST_EQUAL(*iter2, *iter1);
     TEST_EQUAL(iter1.get_wdf(), 1);
     TEST_EQUAL(iter2.get_wdf(), 1);
-    //TEST_EQUAL(iter1.get_termfreq(), 0);
+    // TEST_EQUAL(iter1.get_termfreq(), 0);
     TEST_EQUAL(iter2.get_termfreq(), 1);
 
     iter1++;
@@ -135,7 +135,7 @@ DEFINE_TESTCASE(adddoc2, writable) {
     TEST_EQUAL(*iter2, *iter1);
     TEST_EQUAL(iter1.get_wdf(), 4);
     TEST_EQUAL(iter2.get_wdf(), 4);
-    //TEST_EQUAL(iter1.get_termfreq(), 0);
+    // TEST_EQUAL(iter1.get_termfreq(), 0);
     TEST_EQUAL(iter2.get_termfreq(), 1);
 
     iter1++;
@@ -178,19 +178,19 @@ DEFINE_TESTCASE(adddoc2, writable) {
     iter2 = doc2.termlist_begin();
     TEST(iter2 != doc2.termlist_end());
     TEST_EQUAL(*iter2, "bag");
-    //TEST_EQUAL(iter2.get_termfreq(), 0);
+    // TEST_EQUAL(iter2.get_termfreq(), 0);
     iter2++;
     TEST(iter2 != doc2.termlist_end());
     TEST_EQUAL(*iter2, "bar");
-    //TEST_EQUAL(iter2.get_termfreq(), 0);
+    // TEST_EQUAL(iter2.get_termfreq(), 0);
     iter2++;
     TEST(iter2 != doc2.termlist_end());
     TEST_EQUAL(*iter2, "bat");
-    //TEST_EQUAL(iter2.get_termfreq(), 0);
+    // TEST_EQUAL(iter2.get_termfreq(), 0);
     iter2++;
     TEST(iter2 != doc2.termlist_end());
     TEST_EQUAL(*iter2, "foo");
-    //TEST_EQUAL(iter2.get_termfreq(), 0);
+    // TEST_EQUAL(iter2.get_termfreq(), 0);
     iter2++;
     TEST(iter2 == doc2.termlist_end());
 
@@ -206,7 +206,7 @@ DEFINE_TESTCASE(adddoc2, writable) {
     TEST_EQUAL(iter1.get_wdf(), 0);
     TEST_EQUAL(iter2.get_wdf(), 0);
     TEST_EQUAL(iter1.get_termfreq(), 1);
-    //TEST_EQUAL(iter2.get_termfreq(), 0);
+    // TEST_EQUAL(iter2.get_termfreq(), 0);
     TEST(iter1.positionlist_begin() == iter1.positionlist_end());
     TEST(iter2.positionlist_begin() == iter2.positionlist_end());
 
@@ -219,7 +219,7 @@ DEFINE_TESTCASE(adddoc2, writable) {
     TEST_EQUAL(iter1.get_wdf(), 9);
     TEST_EQUAL(iter2.get_wdf(), 9);
     TEST_EQUAL(iter1.get_termfreq(), 2);
-    //TEST_EQUAL(iter2.get_termfreq(), 0);
+    // TEST_EQUAL(iter2.get_termfreq(), 0);
 
     Xapian::PositionIterator pi1;
     pi1 = iter1.positionlist_begin();
@@ -238,7 +238,7 @@ DEFINE_TESTCASE(adddoc2, writable) {
     TEST_EQUAL(iter1.get_wdf(), 0);
     TEST_EQUAL(iter2.get_wdf(), 0);
     TEST_EQUAL(iter1.get_termfreq(), 1);
-    //TEST_EQUAL(iter2.get_termfreq(), 0);
+    // TEST_EQUAL(iter2.get_termfreq(), 0);
     TEST(iter1.positionlist_begin() == iter1.positionlist_end());
     TEST(iter2.positionlist_begin() == iter2.positionlist_end());
 
@@ -251,7 +251,7 @@ DEFINE_TESTCASE(adddoc2, writable) {
     TEST_EQUAL(iter1.get_wdf(), 0);
     TEST_EQUAL(iter2.get_wdf(), 0);
     TEST_EQUAL(iter1.get_termfreq(), 2);
-    //TEST_EQUAL(iter2.get_termfreq(), 0);
+    // TEST_EQUAL(iter2.get_termfreq(), 0);
 
     Xapian::PositionIterator temp1 = iter1.positionlist_begin();
     pi1 = temp1;
@@ -903,22 +903,22 @@ DEFINE_TESTCASE(replacedoc1, writable) {
     db.replace_document(did, doc2);
 
     Xapian::Document doc3 = db.get_document(did);
-    Xapian::TermIterator tIter = doc3.termlist_begin();
-    TEST_EQUAL(*tIter, "bar");
-    Xapian::PositionIterator pIter = tIter.positionlist_begin();
-    TEST_EQUAL(*pIter, 4);
-    ++tIter;
-    TEST_EQUAL(*tIter, "foo");
-    Xapian::PositionIterator qIter = tIter.positionlist_begin();
-    TEST_EQUAL(*qIter, 1);
-    ++qIter;
-    TEST_EQUAL(*qIter, 5);
-    ++tIter;
-    TEST_EQUAL(*tIter, "pipco");
-    Xapian::PositionIterator rIter = tIter.positionlist_begin();
-    TEST_EQUAL(*rIter, 2);
-    ++tIter;
-    TEST_EQUAL(tIter, doc3.termlist_end());
+    Xapian::TermIterator t_iter = doc3.termlist_begin();
+    TEST_EQUAL(*t_iter, "bar");
+    Xapian::PositionIterator p_iter = t_iter.positionlist_begin();
+    TEST_EQUAL(*p_iter, 4);
+    ++t_iter;
+    TEST_EQUAL(*t_iter, "foo");
+    Xapian::PositionIterator q_iter = t_iter.positionlist_begin();
+    TEST_EQUAL(*q_iter, 1);
+    ++q_iter;
+    TEST_EQUAL(*q_iter, 5);
+    ++t_iter;
+    TEST_EQUAL(*t_iter, "pipco");
+    Xapian::PositionIterator r_iter = t_iter.positionlist_begin();
+    TEST_EQUAL(*r_iter, 2);
+    ++t_iter;
+    TEST_EQUAL(t_iter, doc3.termlist_end());
     return true;
 }
 
@@ -955,22 +955,22 @@ DEFINE_TESTCASE(replacedoc2, writable) {
     TEST_EQUAL(db.get_doccount(), 1);
 
     Xapian::Document doc3 = db.get_document(did);
-    Xapian::TermIterator tIter = doc3.termlist_begin();
-    TEST_EQUAL(*tIter, "bar");
-    Xapian::PositionIterator pIter = tIter.positionlist_begin();
-    TEST_EQUAL(*pIter, 4);
-    ++tIter;
-    TEST_EQUAL(*tIter, "foo");
-    Xapian::PositionIterator qIter = tIter.positionlist_begin();
-    TEST_EQUAL(*qIter, 1);
-    ++qIter;
-    TEST_EQUAL(*qIter, 5);
-    ++tIter;
-    TEST_EQUAL(*tIter, "pipco");
-    Xapian::PositionIterator rIter = tIter.positionlist_begin();
-    TEST_EQUAL(*rIter, 2);
-    ++tIter;
-    TEST_EQUAL(tIter, doc3.termlist_end());
+    Xapian::TermIterator t_iter = doc3.termlist_begin();
+    TEST_EQUAL(*t_iter, "bar");
+    Xapian::PositionIterator p_iter = t_iter.positionlist_begin();
+    TEST_EQUAL(*p_iter, 4);
+    ++t_iter;
+    TEST_EQUAL(*t_iter, "foo");
+    Xapian::PositionIterator q_iter = t_iter.positionlist_begin();
+    TEST_EQUAL(*q_iter, 1);
+    ++q_iter;
+    TEST_EQUAL(*q_iter, 5);
+    ++t_iter;
+    TEST_EQUAL(*t_iter, "pipco");
+    Xapian::PositionIterator r_iter = t_iter.positionlist_begin();
+    TEST_EQUAL(*r_iter, 2);
+    ++t_iter;
+    TEST_EQUAL(t_iter, doc3.termlist_end());
 
     did = db.add_document(doc1);
     TEST_EQUAL(did, 31771);
