@@ -2,7 +2,7 @@
  *
  * Copyright 1999,2000,2001 BrightStation PLC
  * Copyright 2002 Ananova Ltd
- * Copyright 2002,2003,2004,2005,2006,2007,2008,2009,2010,2012 Olly Betts
+ * Copyright 2002,2003,2004,2005,2006,2007,2008,2009,2010,2011,2012,2013,2016 Olly Betts
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -41,7 +41,6 @@
 #include "index_utils.h"
 #include "backendmanager.h"
 #include "unixcmds.h"
-#include "utils.h"
 
 using namespace std;
 
@@ -49,8 +48,7 @@ void
 BackendManager::index_files_to_database(Xapian::WritableDatabase & database,
 					const vector<string> & files)
 {
-    FileIndexer f(datadir, files);
-    while (f) database.add_document(f.next());
+    FileIndexer(datadir, files).index_to(database);
 }
 
 /** Create the directory dirname if needed.  Returns true if the
@@ -62,11 +60,11 @@ BackendManager::create_dir_if_needed(const string &dirname)
 {
     // create a directory if not present
     struct stat sbuf;
-    int result = stat(dirname, &sbuf);
+    int result = stat(dirname.c_str(), &sbuf);
     if (result < 0) {
 	if (errno != ENOENT)
 	    throw Xapian::DatabaseOpeningError("Can't stat directory");
-	if (mkdir(dirname, 0700) < 0)
+	if (mkdir(dirname.c_str(), 0700) < 0)
 	    throw Xapian::DatabaseOpeningError("Can't create directory");
 	return true; // Successfully created a directory.
     }
@@ -79,17 +77,17 @@ BackendManager::create_dir_if_needed(const string &dirname)
 Xapian::WritableDatabase
 BackendManager::getwritedb_inmemory(const vector<string> &files)
 {
-    Xapian::WritableDatabase db(Xapian::InMemory::open());
+    Xapian::WritableDatabase db(string(), Xapian::DB_BACKEND_INMEMORY);
     index_files_to_database(db, files);
     return db;
 }
 #endif
 
-#ifdef XAPIAN_HAS_BRASS_BACKEND
+#ifdef XAPIAN_HAS_GLASS_BACKEND
 string
-BackendManager::createdb_brass(const vector<string> &files)
+BackendManager::createdb_glass(const vector<string> &files)
 {
-    string parent_dir = ".brass";
+    string parent_dir = ".glass";
     create_dir_if_needed(parent_dir);
 
     string dbdir = parent_dir + "/db";
@@ -101,7 +99,8 @@ BackendManager::createdb_brass(const vector<string> &files)
     // If the database is readonly, we can reuse it if it exists.
     if (create_dir_if_needed(dbdir)) {
 	// Directory was created, so do the indexing.
-	Xapian::WritableDatabase db(Xapian::Brass::open(dbdir, Xapian::DB_CREATE, 2048));
+	Xapian::WritableDatabase db(dbdir,
+		Xapian::DB_CREATE|Xapian::DB_BACKEND_GLASS, 2048);
 	index_files_to_database(db, files);
 	db.commit();
     }
@@ -109,25 +108,26 @@ BackendManager::createdb_brass(const vector<string> &files)
 }
 
 Xapian::WritableDatabase
-BackendManager::getwritedb_brass(const string & name,
+BackendManager::getwritedb_glass(const string & name,
 				 const vector<string> & files)
 {
-    string dbdir = getwritedb_brass_path(name);
+    string dbdir = getwritedb_glass_path(name);
 
     // For a writable database we need to start afresh each time.
     rm_rf(dbdir);
     (void)create_dir_if_needed(dbdir);
 
     // directory was created, so do the indexing.
-    Xapian::WritableDatabase db(Xapian::Brass::open(dbdir, Xapian::DB_CREATE, 2048));
+    Xapian::WritableDatabase db(dbdir,
+	    Xapian::DB_CREATE|Xapian::DB_BACKEND_GLASS, 2048);
     index_files_to_database(db, files);
     return db;
 }
 
 std::string
-BackendManager::getwritedb_brass_path(const string & name)
+BackendManager::getwritedb_glass_path(const string & name)
 {
-    string parent_dir = ".brass";
+    string parent_dir = ".glass";
     create_dir_if_needed(parent_dir);
 
     string dbdir = parent_dir;
@@ -153,7 +153,8 @@ BackendManager::createdb_chert(const vector<string> &files)
     // If the database is readonly, we can reuse it if it exists.
     if (create_dir_if_needed(dbdir)) {
 	// Directory was created, so do the indexing.
-	Xapian::WritableDatabase db(Xapian::Chert::open(dbdir, Xapian::DB_CREATE, 2048));
+	Xapian::WritableDatabase db(dbdir,
+		Xapian::DB_CREATE|Xapian::DB_BACKEND_CHERT, 2048);
 	index_files_to_database(db, files);
 	db.commit();
     }
@@ -171,7 +172,8 @@ BackendManager::getwritedb_chert(const string & name,
     (void)create_dir_if_needed(dbdir);
 
     // directory was created, so do the indexing.
-    Xapian::WritableDatabase db(Xapian::Chert::open(dbdir, Xapian::DB_CREATE, 2048));
+    Xapian::WritableDatabase db(dbdir,
+	    Xapian::DB_CREATE|Xapian::DB_BACKEND_CHERT, 2048);
     index_files_to_database(db, files);
     return db;
 }
@@ -190,59 +192,6 @@ BackendManager::getwritedb_chert_path(const string & name)
 
 #endif
 
-#ifdef XAPIAN_HAS_FLINT_BACKEND
-string
-BackendManager::createdb_flint(const vector<string> &files)
-{
-    string parent_dir = ".flint";
-    create_dir_if_needed(parent_dir);
-
-    string dbdir = parent_dir + "/db";
-    for (vector<string>::const_iterator i = files.begin();
-	 i != files.end(); i++) {
-	dbdir += '=';
-	dbdir += *i;
-    }
-    // If the database is readonly, we can reuse it if it exists.
-    if (create_dir_if_needed(dbdir)) {
-	// Directory was created, so do the indexing.
-	Xapian::WritableDatabase db(Xapian::Flint::open(dbdir, Xapian::DB_CREATE, 2048));
-	index_files_to_database(db, files);
-	db.commit();
-    }
-    return dbdir;
-}
-
-Xapian::WritableDatabase
-BackendManager::getwritedb_flint(const string & name,
-				 const vector<string> & files)
-{
-    string dbdir = getwritedb_flint_path(name);
-
-    // For a writable database we need to start afresh each time.
-    rm_rf(dbdir);
-    (void)create_dir_if_needed(dbdir);
-
-    // directory was created, so do the indexing.
-    Xapian::WritableDatabase db(Xapian::Flint::open(dbdir, Xapian::DB_CREATE, 2048));
-    index_files_to_database(db, files);
-    return db;
-}
-
-std::string
-BackendManager::getwritedb_flint_path(const string & name)
-{
-    string parent_dir = ".flint";
-    create_dir_if_needed(parent_dir);
-
-    string dbdir = parent_dir;
-    dbdir += '/';
-    dbdir += name;
-    return dbdir;
-}
-
-#endif
-
 BackendManager::~BackendManager() { }
 
 std::string
