@@ -1,7 +1,7 @@
 /** @file backendmanager_multi.cc
  * @brief BackendManager subclass for multi databases.
  */
-/* Copyright (C) 2007,2008,2009 Olly Betts
+/* Copyright (C) 2007,2008,2009,2011,2012,2013,2015 Olly Betts
  * Copyright (C) 2008 Lemur Consulting Ltd
  *
  * This program is free software; you can redistribute it and/or
@@ -23,9 +23,9 @@
 
 #include "backendmanager_multi.h"
 
+#include "filetests.h"
 #include "index_utils.h"
 #include "str.h"
-#include "utils.h"
 
 #include <cstdio> // For rename().
 #include <cstring>
@@ -36,19 +36,13 @@ using namespace std;
 BackendManagerMulti::BackendManagerMulti(const std::string & subtype_)
 	: subtype(subtype_)
 {
-    if (!(false
-#ifdef XAPIAN_HAS_BRASS_BACKEND
-	  || subtype == "brass"
+#ifdef XAPIAN_HAS_GLASS_BACKEND
+    if (subtype == "glass") return;
 #endif
 #ifdef XAPIAN_HAS_CHERT_BACKEND
-	  || subtype == "chert"
+    if (subtype == "chert") return;
 #endif
-#ifdef XAPIAN_HAS_FLINT_BACKEND
-	  || subtype == "flint"
-#endif
-	 )) {
-	throw ("Unknown backend type \"" + subtype + "\" specified for multi database subdatabases");
-    }
+    throw ("Unknown backend type \"" + subtype + "\" specified for multi database subdatabases");
 }
 
 std::string
@@ -89,39 +83,35 @@ BackendManagerMulti::createdb_multi(const vector<string> & files)
 
     // Open NUMBER_OF_SUB_DBS databases and index files to them alternately so
     // a multi-db combining them contains the documents in the expected order.
-    Xapian::WritableDatabase dbs[NUMBER_OF_SUB_DBS];
+    Xapian::WritableDatabase dbs;
+    int flags = Xapian::DB_CREATE_OR_OVERWRITE;
+    if (subtype == "glass") {
+	flags |= Xapian::DB_BACKEND_GLASS;
+    } else if (subtype == "chert") {
+	flags |= Xapian::DB_BACKEND_CHERT;
+    } else {
+	string msg = "Unknown multidb subtype: ";
+	msg += subtype;
+	throw msg;
+    }
+    string dbbase = dbdir;
+    dbbase += '/';
+    dbbase += dbname;
+    dbbase += "___";
+    size_t dbbase_len = dbbase.size();
+    string line = subtype;
+    line += ' ';
+    line += dbname;
+    line += "___";
     for (size_t n = 0; n < NUMBER_OF_SUB_DBS; ++n) {
-	string subdbdir = dbname;
-	subdbdir += "___";
-	subdbdir += str(n);
-#if defined XAPIAN_HAS_BRASS_BACKEND
-	if (subtype == "brass") {
-	    dbs[n] = Xapian::Brass::open(dbdir + "/" + subdbdir, Xapian::DB_CREATE_OR_OVERWRITE);
-	    out << "brass " << subdbdir << '\n';
-	}
-#endif
-#if defined XAPIAN_HAS_CHERT_BACKEND
-	if (subtype == "chert") {
-	    dbs[n] = Xapian::Chert::open(dbdir + "/" + subdbdir, Xapian::DB_CREATE_OR_OVERWRITE);
-	    out << "chert " << subdbdir << '\n';
-	}
-#endif
-#ifdef XAPIAN_HAS_FLINT_BACKEND
-	if (subtype == "flint") {
-	    dbs[n] = Xapian::Flint::open(dbdir + "/" + subdbdir, Xapian::DB_CREATE_OR_OVERWRITE);
-	    out << "flint " << subdbdir << '\n';
-	}
-#endif
-	
+	dbbase += str(n);
+	dbs.add_database(Xapian::WritableDatabase(dbbase, flags));
+	dbbase.resize(dbbase_len);
+	out << line << n << '\n';
     }
     out.close();
 
-    size_t c = 0;
-    FileIndexer f(get_datadir(), files);
-    while (f) {
-	dbs[c].add_document(f.next());
-	c = (c + 1) % NUMBER_OF_SUB_DBS;
-    }
+    FileIndexer(get_datadir(), files).index_to(dbs);
 
     rename(tmpfile.c_str(), dbpath.c_str());
 
