@@ -32,7 +32,7 @@
 #ifdef HAVE_FORK
 # include <signal.h>
 # include <sys/types.h>
-# include <sys/socket.h>
+# include "safesyssocket.h"
 # include <sys/wait.h>
 # include <unistd.h>
 // Some older systems had SIGCLD rather than SIGCHLD.
@@ -112,12 +112,15 @@ launch_xapian_tcpsrv(const string & args)
     // if xapian-tcpsrv doesn't start listening successfully.
     signal(SIGCHLD, SIG_DFL);
 try_next_port:
-    string cmd = XAPIAN_TCPSRV " --one-shot --interface " LOCALHOST " --port " + str(port) + " " + args;
+    string cmd = XAPIAN_TCPSRV " --one-shot --interface " LOCALHOST " --port ";
+    cmd += str(port);
+    cmd += " ";
+    cmd += args;
 #ifdef HAVE_VALGRIND
     if (RUNNING_ON_VALGRIND) cmd = "./runsrv " + cmd;
 #endif
     int fds[2];
-    if (socketpair(AF_UNIX, SOCK_STREAM, PF_UNSPEC, fds) < 0) {
+    if (socketpair(AF_UNIX, SOCK_STREAM|SOCK_CLOEXEC, PF_UNSPEC, fds) < 0) {
 	string msg("Couldn't create socketpair: ");
 	msg += strerror(errno);
 	throw msg;
@@ -128,12 +131,20 @@ try_next_port:
 	// Child process.
 	close(fds[0]);
 	// Connect stdout and stderr to the socket.
+	//
+	// Make sure the socket isn't fd 1 or 2.  We need to ensure that
+	// FD_CLOEXEC isn't set for stdout or stderr (which creating them with
+	// dup2() achieves), and that we close fds[1].  The cleanest way to
+	// address this seems to be to turn the unusual situation into the
+	// usual one.
+	if (fds[1] == 1 || fds[1] == 2) {
+	    dup2(fds[1], 3);
+	    fds[1] = 3;
+	}
 	dup2(fds[1], 1);
 	dup2(fds[1], 2);
-	if (fds[1] != 1 && fds[1] != 2) {
-	    close(fds[1]);
-	}
-	execl("/bin/sh", "/bin/sh", "-c", cmd.c_str(), (void*)NULL);
+	close(fds[1]);
+	execl("/bin/sh", "/bin/sh", "-c", cmd.c_str(), static_cast<void*>(0));
 	_exit(-1);
     }
 
@@ -246,7 +257,10 @@ launch_xapian_tcpsrv(const string & args)
     int port = DEFAULT_PORT;
 
 try_next_port:
-    string cmd = XAPIAN_TCPSRV " --one-shot --interface " LOCALHOST " --port " + str(port) + " " + args;
+    string cmd = XAPIAN_TCPSRV " --one-shot --interface " LOCALHOST " --port ";
+    cmd += str(port);
+    cmd += " ";
+    cmd += args;
 
     // Create a pipe so we can read stdout/stderr from the child process.
     HANDLE hRead, hWrite;
@@ -280,7 +294,7 @@ try_next_port:
     CloseHandle(procinfo.hThread);
 
     string output;
-    FILE *fh = fdopen(_open_osfhandle((intptr_t)hRead, O_RDONLY), "r");
+    FILE *fh = fdopen(_open_osfhandle(intptr_t(hRead), O_RDONLY), "r");
     while (true) {
 	char buf[256];
 	if (fgets(buf, sizeof(buf), fh) == NULL) {
